@@ -1,20 +1,23 @@
 package Date::ICal::Duration;
 
 use strict;
+use warnings;
 use Carp;
 
 use vars qw($VERSION );
-$VERSION = (qw'$Revision: 1.61 $')[1];
+$VERSION = '2.'.(qw'$Rev: 681 $')[1];
 
 # Documentation {{{
 
+=encoding utf8
+
 =head1 NAME
 
 Date::ICal::Duration - durations in iCalendar format, for math purposes.
 
 =head1 VERSION
 
-$Revision: 1.61 $
+$Revision: 681 $
 
 =head1 SYNOPSIS
 
@@ -563,4 +566,15 @@ sub _wd  {
     }
 } # }}}
 
+=head1 LICENSE AND COPYRIGHT
+
+© 2001-2022 Rich Bowen
+
+© 2022-2023 Michal Josef Špaček
+
+This library is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
+=cut
+
 1;
